metadata(version="3.3.4")

require("getopt")
require("itertools")
# require("linecache") TODO
require("time")
require("traceback")

module("timeit.py")
